==> geostore-0.1.5.tar.gz: geostore-0.1.5/geostore/stac_format.py <==
STAC_ASSETS_KEY = "assets"
STAC_DESCRIPTION_KEY = "description"
STAC_EXTENSIONS_KEY = "stac_extensions"
STAC_EXTENT_BBOX_KEY = "bbox"
STAC_EXTENT_KEY = "extent"
STAC_EXTENT_SPATIAL_KEY = "spatial"
STAC_EXTENT_TEMPORAL_INTERVAL_KEY = "interval"
STAC_EXTENT_TEMPORAL_KEY = "temporal"
STAC_FILE_CHECKSUM_KEY = "file:checksum"
STAC_GEOMETRY_KEY = "geometry"
STAC_HREF_KEY = "href"
STAC_ID_KEY = "id"
STAC_LICENSE_KEY = "license"
STAC_LINKS_KEY = "links"
STAC_MEDIA_TYPE_GEOJSON = "application/geo+json"
STAC_MEDIA_TYPE_JSON = "application/json"
STAC_PROPERTIES_DATETIME_KEY = "datetime"
STAC_PROPERTIES_KEY = "properties"
STAC_REL_CHILD = "child"
STAC_REL_ITEM = "item"
STAC_REL_KEY = "rel"
STAC_REL_PARENT = "parent"
STAC_REL_ROOT = "root"
STAC_REL_SELF = "self"
STAC_TITLE_KEY = "title"
STAC_TYPE_CATALOG = "Catalog"
STAC_TYPE_COLLECTION = "Collection"
STAC_TYPE_ITEM = "Feature"
STAC_TYPE_KEY = "type"
STAC_VERSION = "1.0.0"
STAC_VERSION_KEY = "stac_version"

LINZ_STAC_EXTENSIONS_PATH = "stac/v0.0.7"
LINZ_SCHEMA_DIRECTORY = f"{LINZ_STAC_EXTENSIONS_PATH}/linz"
LINZ_SCHEMA_PATH = f"{LINZ_SCHEMA_DIRECTORY}/schema.json"
LINZ_STAC_EXTENSION_URL = f"https://linz.github.io/{LINZ_SCHEMA_PATH}"
LINZ_STAC_EXTENSION_KEY_PREFIX = "linz"
LINZ_STAC_CREATED_KEY = f"{LINZ_STAC_EXTENSION_KEY_PREFIX}:created"
LINZ_STAC_SECURITY_CLASSIFICATION_KEY = f"{LINZ_STAC_EXTENSION_KEY_PREFIX}:security_classification"
LINZ_STAC_LIFECYCLE_KEY = f"{LINZ_STAC_EXTENSION_KEY_PREFIX}:lifecycle"
LINZ_STAC_PROVIDERS_KEY = f"{LINZ_STAC_EXTENSION_KEY_PREFIX}:providers"
LINZ_STAC_UPDATED_KEY = f"{LINZ_STAC_EXTENSION_KEY_PREFIX}:updated"

QUALITY_SCHEMA_PATH = f"{LINZ_STAC_EXTENSIONS_PATH}/quality/schema.json"
QUALITY_LINEAGE_KEY = "quality:lineage"

VERSION_VERSION_KEY = "version"

==> geostore-0.1.6.tar.gz: geostore-0.1.6/geostore/stac_format.py <==
STAC_ASSETS_KEY = "assets"
STAC_DESCRIPTION_KEY = "description"
STAC_EXTENSIONS_KEY = "stac_extensions"
STAC_EXTENT_BBOX_KEY = "bbox"
STAC_EXTENT_KEY = "extent"
STAC_EXTENT_SPATIAL_KEY = "spatial"
STAC_EXTENT_TEMPORAL_INTERVAL_KEY = "interval"
STAC_EXTENT_TEMPORAL_KEY = "temporal"
STAC_FILE_CHECKSUM_KEY = "file:checksum"
STAC_GEOMETRY_KEY = "geometry"
STAC_HREF_KEY = "href"
STAC_ID_KEY = "id"
STAC_LICENSE_KEY = "license"
STAC_LINKS_KEY = "links"
STAC_MEDIA_TYPE_GEOJSON = "application/geo+json"
STAC_MEDIA_TYPE_JSON = "application/json"
STAC_PROPERTIES_DATETIME_KEY = "datetime"
STAC_PROPERTIES_KEY = "properties"
STAC_PROVIDERS_KEY = "providers"
STAC_REL_CHILD = "child"
STAC_REL_ITEM = "item"
STAC_REL_KEY = "rel"
STAC_REL_PARENT = "parent"
STAC_REL_ROOT = "root"
STAC_REL_SELF = "self"
STAC_TITLE_KEY = "title"
STAC_TYPE_CATALOG = "Catalog"
STAC_TYPE_COLLECTION = "Collection"
STAC_TYPE_ITEM = "Feature"
STAC_TYPE_KEY = "type"
STAC_VERSION = "1.0.0"
STAC_VERSION_KEY = "stac_version"

LINZ_EXTENSION_BASE_URL = "https://linz.github.io"

LINZ_STAC_EXTENSIONS_PATH = "stac/v0.0.10"
LINZ_SCHEMA_DIRECTORY = f"{LINZ_STAC_EXTENSIONS_PATH}/linz"
LINZ_SCHEMA_PATH = f"{LINZ_SCHEMA_DIRECTORY}/schema.json"
LINZ_STAC_EXTENSION_URL = f"{LINZ_EXTENSION_BASE_URL}/{LINZ_SCHEMA_PATH}"

LINZ_STAC_EXTENSION_KEY_PREFIX = "linz"
LINZ_STAC_CREATED_KEY = "created"
LINZ_STAC_GEOSPATIAL_TYPE_KEY = f"{LINZ_STAC_EXTENSION_KEY_PREFIX}:geospatial_type"
LINZ_STAC_HISTORY_KEY = f"{LINZ_STAC_EXTENSION_KEY_PREFIX}:history"
LINZ_STAC_LIFECYCLE_KEY = f"{LINZ_STAC_EXTENSION_KEY_PREFIX}:lifecycle"
LINZ_STAC_PROVIDERS_KEY = f"{LINZ_STAC_EXTENSION_KEY_PREFIX}:providers"
LINZ_STAC_SECURITY_CLASSIFICATION_KEY = f"{LINZ_STAC_EXTENSION_KEY_PREFIX}:security_classification"
LINZ_STAC_UPDATED_KEY = "updated"

QUALITY_SCHEMA_PATH = f"{LINZ_STAC_EXTENSIONS_PATH}/quality/schema.json"

PROJECTION_EPSG_KEY = "proj:epsg"

VERSION_VERSION_KEY = "version"
